from __future__ import annotations
from AinaTheme.utils import custom_colors
from AinaTheme.aina_class import Aina

theme = Aina(
    primary_hue=custom_colors.primary,
    secondary_hue=custom_colors.secondary,
)


from gradio.themes.utils import colors, fonts, sizes
from gradio.themes import Soft
from typing import Iterable

class Aina(Soft):
    def __init__(
        self,
        *,
        primary_hue: colors.Color | str = colors.indigo,
        secondary_hue: colors.Color | str = colors.indigo,
        neutral_hue: colors.Color | str = colors.gray,
        spacing_size: sizes.Size | str = sizes.spacing_md,
        radius_size: sizes.Size | str = sizes.radius_md,
        text_size: sizes.Size | str = sizes.text_md,
        font: fonts.Font
        | str
        | Iterable[fonts.Font | str] = (
            fonts.GoogleFont("Montserrat"),
            "ui-sans-serif",
            "system-ui",
            "sans-serif",
        ),
        font_mono: fonts.Font
        | str
        | Iterable[fonts.Font | str] = (
            fonts.GoogleFont("IBM Plex Mono"),
            "ui-monospace",
            "Consolas",
            "monospace",
        ),
    ):
        super().__init__(
            primary_hue=primary_hue,
            secondary_hue=secondary_hue,
            neutral_hue=neutral_hue,
            spacing_size=spacing_size,
            radius_size=radius_size,
            text_size=text_size,
            font=font,
            font_mono=font_mono,
        )
        self.name = "aina"
        super().set(
            block_title_text_color="black",
            block_label_text_color="black",
            block_label_text_weight=400,
            block_title_text_weight=400,
            block_title_background_fill="transparent",
            block_label_background_fill="transparent",
            button_border_width="0px",
            input_border_width="2px",
            input_border_color="*panel_border_color",
        )




from setuptools import setup, find_packages

setup(
    name="aina-gradio-theme",
    version="2.1",
    description="Aina Theme is a custom Gradio theme inspired by the visual style of Storj theme. Feel free to use this theme to create Gradio apps that have a visual connection to the world of cloud technology.",
    long_description=open("README.md", 'r').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/projecte-aina/aina-gradio-theme",
    author="Projecte Aina",
    author_email="aina@bsc.es",
    license="Apache License 2.0",
    packages=find_packages(),
)
